# == Class: oslo
#
# Full description of class oslo here.
#
# === Parameters
#
# [*sample_parameter*]
#   Explanation of what this parameter affects and what it defaults to.
#
class oslo {

  include ::oslo::params

}
